# mt-ban-ascii.pl
# - Deny or moderate ASCII or Latin-1 comment using MT3 CommentFilter API
#
# It requires Perl 5.8 or over.
#
# Author:  Tatsuhiko Miyagawa <miyagawa at bulknews.net>
# License: same as Perl
#
# Ported to MT 3.3 TBPingThrottleFilter by Yujiro ARAKI.
# asciiTBPingfilter.pl
# 2006.07.17 1.00

package MT::Plugin::asciiTBPingfilter;

use strict;
use MT;
use base qw(MT::Plugin);

our $VERSION;

# logging
our $log = 0;

sub BEGIN {
    $VERSION = '1.00';
    my $plugin = MT::Plugin::asciiTBPingfilter->new ({
        name => 'ASCII TBPing Filter Plugin',
        description => 'Filter only ascii trackback ping.',
        doc_link => 'http://www.koikikukan.com/archives/2006/xx/xx-xxxxxx.php',
        version => $VERSION,
        blog_config_template => 'config.tmpl',
        settings => new MT::PluginSettings ([
        ['asciiTBPingfilter', { Default => '0', Scope => 'blog' }],
        ]),
        });
    MT->add_plugin($plugin);
    MT->add_callback('TBPingThrottleFilter', 5, $plugin, sub { ascii_tbping_filter($plugin, @_) });
}

sub ascii_tbping_filter {
    my $plugin = shift;
    my($eh, $app, $tb) = @_;

    my $q = $app->{query};
    my $tbping = MT::TBPing->new;
    $tbping->title($q->param('title') || '');
    $tbping->excerpt($q->param('excerpt') || '');
    $tbping->blog_name($q->param('blog_name') || '');

    eval { require Encode; };
    if ($@) {
        $app->log("Please use perl 5.8 for this plugin.");
        return 1;
    }
    my $text = Encode::decode(MT::ConfigMgr->instance->PublishCharset, $tbping->all_text);
    if ($text =~ /^[\x00-\xff]+$/) {
        $app->log("Filter ascii trackback ping. URL:" . $q->param('url') . " IP:" . $app->remote_ip) if $log;
        return 0;
    }
    return 1;
}

1;
